==> jangaroo-sdk-0.9.3.zip: joo/classes/flash/text/FontStyle.js <==
joo.classLoader.prepare("package flash.text",/* {*/


/**
 * The FontStyle class provides values for the TextRenderer class.
 * @see TextRenderer
 *
 */
"public final class FontStyle",1,function($$private){;return[ 
  /**
   * Defines the bold style of a font for the <code>fontStyle</code> parameter in the <code>setAdvancedAntiAliasingTable()</code> method. Use the syntax <code>FontStyle.BOLD</code>.
   * @see TextRenderer#setAdvancedAntiAliasingTable()
   *
   */
  "public static const",{ BOLD/*:String*/ : "bold"},
  /**
   * Defines the combined bold and italic style of a font for the <code>fontStyle</code> parameter in the <code>setAdvancedAntiAliasingTable()</code> method. Use the syntax <code>FontStyle.BOLD_ITALIC</code>.
   * @see TextRenderer#setAdvancedAntiAliasingTable()
   *
   */
  "public static const",{ BOLD_ITALIC/*:String*/ : "boldItalic"},
  /**
   * Defines the italic style of a font for the <code>fontStyle</code> parameter in the <code>setAdvancedAntiAliasingTable()</code> method. Use the syntax <code>FontStyle.ITALIC</code>.
   * @see TextRenderer#setAdvancedAntiAliasingTable()
   *
   */
  "public static const",{ ITALIC/*:String*/ : "italic"},
  /**
   * Defines the plain style of a font for the <code>fontStyle</code> parameter in the <code>setAdvancedAntiAliasingTable()</code> method. Use the syntax <code>FontStyle.REGULAR</code>.
   * @see TextRenderer#setAdvancedAntiAliasingTable()
   *
   */
  "public static const",{ REGULAR/*:String*/ : "regular"},
];},[],[], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/flash/text/FontStyle.js <==
joo.classLoader.prepare("package flash.text",/* {*/


/**
 * The FontStyle class provides values for the TextRenderer class.
 * @see TextRenderer
 *
 */
"public final class FontStyle",1,function($$private){return[ 
  /**
   * Defines the bold style of a font for the <code>fontStyle</code> parameter in the <code>setAdvancedAntiAliasingTable()</code> method. Use the syntax <code>FontStyle.BOLD</code>.
   * @see TextRenderer#setAdvancedAntiAliasingTable()
   *
   */
  "public static const",{ BOLD/*:String*/ : "bold"},
  /**
   * Defines the combined bold and italic style of a font for the <code>fontStyle</code> parameter in the <code>setAdvancedAntiAliasingTable()</code> method. Use the syntax <code>FontStyle.BOLD_ITALIC</code>.
   * @see TextRenderer#setAdvancedAntiAliasingTable()
   *
   */
  "public static const",{ BOLD_ITALIC/*:String*/ : "boldItalic"},
  /**
   * Defines the italic style of a font for the <code>fontStyle</code> parameter in the <code>setAdvancedAntiAliasingTable()</code> method. Use the syntax <code>FontStyle.ITALIC</code>.
   * @see TextRenderer#setAdvancedAntiAliasingTable()
   *
   */
  "public static const",{ ITALIC/*:String*/ : "italic"},
  /**
   * Defines the plain style of a font for the <code>fontStyle</code> parameter in the <code>setAdvancedAntiAliasingTable()</code> method. Use the syntax <code>FontStyle.REGULAR</code>.
   * @see TextRenderer#setAdvancedAntiAliasingTable()
   *
   */
  "public static const",{ REGULAR/*:String*/ : "regular"},
undefined];},[],[], "0.8.0", "0.9.12"
);
